<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>AddCommentWindow</name>
    <message>
        <location filename="AddComment.py" line="59"/>
        <source>Add image</source>
        <translation type="unfinished">Изображение</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="67"/>
        <source>HTML</source>
        <translation type="unfinished">HTML</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="83"/>
        <source>Undo</source>
        <translation type="unfinished">Назад</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="91"/>
        <source>Redo</source>
        <translation type="unfinished">Вперед</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="99"/>
        <source>Send</source>
        <translation type="unfinished">Отправить</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="168"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="120"/>
        <source>The comment is empty!</source>
        <translation type="unfinished">Поле текста не заполнено!</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="126"/>
        <source>Do you want to send commentt with empty subject?</source>
        <translation type="unfinished">Вы действительно хотите отправить комментарий без темы?</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="144"/>
        <source>Choose poster for this comment:</source>
        <translation type="unfinished">Выберите автора этого комментария: </translation>
    </message>
    <message>
        <location filename="AddComment.py" line="149"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="AddComment.py" line="168"/>
        <source>Comment was send</source>
        <translation type="unfinished">Комментарий отправлен</translation>
    </message>
</context>
<context>
    <name>AddPostWindow</name>
    <message>
        <location filename="AddPost.py" line="53"/>
        <source>Subject</source>
        <translation type="unfinished">Тема</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="64"/>
        <source>Edit</source>
        <translation type="unfinished">Изменить</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="65"/>
        <source>Preview</source>
        <translation type="unfinished">Просмотр</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="601"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="82"/>
        <source>Post was edited</source>
        <translation type="unfinished">Пост был редактирован</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="150"/>
        <source>Add image</source>
        <translation type="unfinished">Изображение</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="158"/>
        <source>HTML</source>
        <translation type="unfinished">HTML</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="166"/>
        <source>Options</source>
        <translation type="unfinished">Опции</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="174"/>
        <source>Save</source>
        <translation type="unfinished">Сохранить</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="183"/>
        <source>Undo</source>
        <translation type="unfinished">Отмена</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="191"/>
        <source>Redo</source>
        <translation type="unfinished">Возврат</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="200"/>
        <source>Send to..</source>
        <translation type="unfinished">Отправить</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="205"/>
        <source>Send</source>
        <translation type="unfinished">Отправить</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="601"/>
        <source>The text is empty!</source>
        <translation type="unfinished">Поле с текстом не заполнено!</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="273"/>
        <source>Do you want to send message with empty subject?</source>
        <translation type="unfinished">Вы действительно хотите послать сообщение без темы?</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="304"/>
        <source>Post is edit</source>
        <translation type="unfinished">Пост редактирован</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="326"/>
        <source>Add picture</source>
        <translation type="unfinished">Добавить изображение</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="327"/>
        <source>Link to the image (URL)</source>
        <translation type="unfinished">Ссылка на изображение</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="490"/>
        <source>Add</source>
        <translation type="unfinished">Добавить</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="355"/>
        <source>Add link</source>
        <translation type="unfinished">Добавить ссылку</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="408"/>
        <source>Link</source>
        <translation type="unfinished">Ссылка</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="391"/>
        <source>Add html tags</source>
        <translation type="unfinished">Добавить html тег</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="394"/>
        <source>Bold</source>
        <translation type="unfinished">Жирный</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="396"/>
        <source>Italic</source>
        <translation type="unfinished">Курсив</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="398"/>
        <source>Center</source>
        <translation type="unfinished">По центру</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="400"/>
        <source>Right</source>
        <translation type="unfinished">По правом краю</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="402"/>
        <source>Left</source>
        <translation type="unfinished">По левому краю</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="404"/>
        <source>Justify</source>
        <translation type="unfinished">По ширине</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="406"/>
        <source>Color</source>
        <translation type="unfinished">Цвет</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="477"/>
        <source>Add option</source>
        <translation type="unfinished">Добавить опцию</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="487"/>
        <source>Tags (comma separated)</source>
        <translation type="unfinished">Теги (через запятую)</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="508"/>
        <source>Message will be lost! Continue? </source>
        <translation type="unfinished">Сообщение будет утеряно! Продолжить?</translation>
    </message>
    <message>
        <location filename="AddPost.py" line="582"/>
        <source>Post was save in drafts. See on main menu.</source>
        <translation type="unfinished">Пост сохранен в черновиках. Смотрите в
главном меню.</translation>
    </message>
</context>
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="AddProfile.py" line="50"/>
        <source>Login</source>
        <translation type="unfinished">Логин</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="52"/>
        <source>Password</source>
        <translation type="unfinished">Пароль</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="65"/>
        <source>Blog Service</source>
        <translation type="unfinished">Сервис</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="115"/>
        <source>Delete account</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="121"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="124"/>
        <source>Add account</source>
        <translation type="unfinished">Добавить</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="276"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="188"/>
        <source>Please, fill all fields!</source>
        <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="261"/>
        <source>Do you really want to delete account?</source>
        <translation type="unfinished">Вы действительно хотите удалить аккаунт?</translation>
    </message>
    <message>
        <location filename="AddProfile.py" line="276"/>
        <source>Account was deleted</source>
        <translation type="unfinished">Аккаунт удален</translation>
    </message>
</context>
<context>
    <name>ComTree</name>
    <message>
        <location filename="TreeMessage.py" line="236"/>
        <source>no subject</source>
        <translation type="unfinished">без темы</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="HomePage.py" line="94"/>
        <source>Personal info:</source>
        <translation type="unfinished">Персональная информация:</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="97"/>
        <source>Nick: </source>
        <translation type="unfinished">Имя:</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="101"/>
        <source>Birthday: </source>
        <translation type="unfinished">Дата рождения: </translation>
    </message>
    <message>
        <location filename="HomePage.py" line="105"/>
        <source>City: </source>
        <translation type="unfinished">Город: </translation>
    </message>
    <message>
        <location filename="HomePage.py" line="109"/>
        <source>Blog service: </source>
        <translation type="unfinished">Сервис: </translation>
    </message>
    <message>
        <location filename="HomePage.py" line="146"/>
        <source>Photo</source>
        <translation type="unfinished">Фото</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="174"/>
        <source>Add post</source>
        <translation type="unfinished">Добавить пост</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="175"/>
        <source>My posts</source>
        <translation type="unfinished">Мои посты</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="176"/>
        <source>Friends&apos; posts</source>
        <translation type="unfinished">Посты друзей</translation>
    </message>
    <message>
        <location filename="HomePage.py" line="177"/>
        <source>Friends</source>
        <translation type="unfinished">Друзья</translation>
    </message>
</context>
<context>
    <name>InfoFriend</name>
    <message>
        <location filename="InfoFriend.py" line="56"/>
        <source>Posts</source>
        <translation type="unfinished">Посты</translation>
    </message>
    <message>
        <location filename="InfoFriend.py" line="57"/>
        <source>Friends</source>
        <translation type="unfinished">Друзья</translation>
    </message>
</context>
<context>
    <name>ListFriends</name>
    <message>
        <location filename="ListFriends.py" line="62"/>
        <source>Refresh message</source>
        <translation type="unfinished">Обновление сообщений</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="63"/>
        <source>Don&apos;t show this message again</source>
        <translation type="unfinished">Не показывать это сообщение снова</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="64"/>
        <source>Press &quot;Refresh&quot; to update list</source>
        <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления списка</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="117"/>
        <source>Refresh</source>
        <translation type="unfinished">Обновить</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="126"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="179"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="150"/>
        <source>Do you really want to delete friend?</source>
        <translation type="unfinished">Вы действительно хотите удалить друга?</translation>
    </message>
    <message>
        <location filename="ListFriends.py" line="179"/>
        <source>Please, choose friends to delete!</source>
        <translation type="unfinished">Пожалуйста, выберите удаляемого друга</translation>
    </message>
</context>
<context>
    <name>ListFriendsPosts</name>
    <message>
        <location filename="ListFriendsPosts.py" line="60"/>
        <source>Refresh</source>
        <translation type="unfinished">Обновить</translation>
    </message>
    <message>
        <location filename="ListFriendsPosts.py" line="62"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
</context>
<context>
    <name>ListMyPosts</name>
    <message>
        <location filename="ListMyPosts.py" line="62"/>
        <source>Sort by:</source>
        <translation type="unfinished">Сортировать по: </translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="69"/>
        <source>On date</source>
        <translation type="unfinished">Дате</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="70"/>
        <source>On title</source>
        <translation type="unfinished">Теме</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="71"/>
        <source>On read/unread</source>
        <translation type="unfinished">Прочитанные/непрочитанные</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="512"/>
        <source>Filters</source>
        <translation type="unfinished">Фильтры</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="101"/>
        <source>Ctrl+N</source>
        <translation type="unfinished">Ctrl+N</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="123"/>
        <source>Refresh message</source>
        <translation type="unfinished">Обновить</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="124"/>
        <source>Don&apos;t show this message again</source>
        <translation type="unfinished">Не показывать это сообщение снова</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="125"/>
        <source>Press &quot;Refresh&quot; to update post</source>
        <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления поста</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="144"/>
        <source>no subject</source>
        <translation type="unfinished">без темы</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="194"/>
        <source>Refresh</source>
        <translation type="unfinished">Обновить</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="203"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="548"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="227"/>
        <source>Do you really want to delete post?</source>
        <translation type="unfinished">Вы действительно хотите удалить пост?</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="255"/>
        <source>Please, choose messages to delete!</source>
        <translation type="unfinished">Выберите сообщение для удаления!</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="337"/>
        <source>By author</source>
        <translation type="unfinished">По автору</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="339"/>
        <source>By date</source>
        <translation type="unfinished">По дате</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="341"/>
        <source>By read/unread</source>
        <translation type="unfinished">Прочитанные/непрочитанные</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="343"/>
        <source>By content</source>
        <translation type="unfinished">По содержимому</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="350"/>
        <source>Search in results</source>
        <translation type="unfinished">Искать в найденном</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="424"/>
        <source>Choose poster:</source>
        <translation type="unfinished">Выберите автора:</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="533"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="485"/>
        <source>Search text:</source>
        <translation type="unfinished">Введите текст:</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="513"/>
        <source>Choose date:</source>
        <translation type="unfinished">Выберите дату поиска:</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="514"/>
        <source>Since: </source>
        <translation type="unfinished">С: </translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="515"/>  
        <source>To: </source>
        <translation type="unfinished">До: </translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="548"/>
        <source>Date in first field should be less!</source>
        <translation type="unfinished">Первая дата должна быть раньше второй!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="MainWindow.py" line="469"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="60"/>
        <source>&amp;New Account</source>
        <translation type="unfinished">&amp;Новый аккаунт</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="61"/>
        <source>&amp;Edit Accounts</source>
        <translation type="unfinished">&amp;Редактировать аккаунт</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="92"/>
        <source>Draft</source>
        <translation type="unfinished">Черновик</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="438"/>
        <source>Drafts</source>
        <translation type="unfinished">Черновики</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="101"/>
        <source>Send</source>
        <translation type="unfinished">Отправить</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="103"/>
        <source>Edit</source>
        <translation type="unfinished">Изменить</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="105"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="144"/>
        <source>no subject</source>
        <translation type="unfinished">без темы</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="179"/>
        <source>List of drafts is empty!</source>
        <translation type="unfinished">Список черновиков - пустой!</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="183"/>
        <source>Please, choose messages!</source>
        <translation type="unfinished">Пожалуйста, выберите сообщение!</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="214"/>
        <source>About Scribo</source>
        <translation type="unfinished">О приложении</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="223"/>
        <source>You can add us to your friends to leave your feedback</source>
        <translation type="unfinished">Вы можете добавить нас в друзья, чтобы оставлять свои отклики.</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="224"/>
        <source>Add friend</source>
        <translation type="unfinished">Добавить в друзья</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="248"/>
        <source>Friend is added</source>
        <translation type="unfinished">Друг добавлен</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="254"/>
        <source>We wasn&apos;t added to the friend. May be, we
                              don&apos;t have LiveJournal account, then you can adds it.</source>
        <translation type="unfinished">Мы не были добавлены в друзья, возможно потому ,что у вас нет учетной записи на LJ. </translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="435"/>
        <source>Settings</source>
        <translation type="unfinished">Настройки</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="284"/>
        <source>Use proxy connections</source>
        <translation type="unfinished">Использовать прокси соединение</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="288"/>
        <source>Proxy: </source>
        <translation type="unfinished">Прокси: </translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="289"/>
        <source>Port: </source>
        <translation type="unfinished">Порт: </translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="290"/>
        <source>Font: </source>
        <translation type="unfinished">Шрифт: </translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="300"/>
        <source>Choose font</source>
        <translation type="unfinished">Выберите шрифт </translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="416"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="423"/>
        <source>E&amp;xit</source>
        <translation type="unfinished">Выход</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="424"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="432"/>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="448"/>
        <source>Menu</source>
        <translation type="unfinished">Меню</translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="469"/>
        <source>Do you really want to quit?</source>
        <translation type="unfinished">Вы действительно хотите выйти?</translation>
    </message>
</context>
<context>
    <name>MyProgress</name>
    <message>
        <location filename="ListMyPosts.py" line="639"/>
        <source>Operation is in progress.</source>
        <translation type="unfinished">Операция выполняется</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="640"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
    <message>
        <location filename="ListMyPosts.py" line="642"/>
        <source>Receiving data...</source>
        <translation type="unfinished">Получение данных...</translation>
    </message>
</context>
<context>
    <name>WarningExc</name>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid username. Check your user name and try again.</source>
        <translation type="unfinished">Неправильное имя пользователя. Проверьте имя и попробуйте войти снова.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid password. Check your password and try again.</source>
        <translation type="unfinished">Введён неправильный пароль. Проверьте его и попробуйте войти снова. </translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't use custom/private security on shared/community journals</source>
        <translation type="unfinished">Ошибка безопасности. Возможно Вам запрещен доступ к этой операции.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Poll error</source>
        <translation type="unfinished">Ошибка опроса</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Error adding one or more friends. Try again or use web interface.</source>
        <translation type="unfinished">Ошибка добавления друга (друзей). Попробуйте снова или добавьте используя веб интерфейс.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Session expired. Restart application please.</source>
        <translation type="unfinished">Срок сессии истёк. Перезагрузите приложение пожалуйста.</translation>
    </message>
        <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't post as non-user. Please login or use web interface.</source>
        <translation type="unfinished">Невозможно отправить пост. Залогиньтесь пожалуйста.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Banned from journal</source>
        <translation type="unfinished">Вы забанены в этом журнале </translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't make back-dated entries in non-personal journal.</source>
        <translation type="unfinished">Вы не можете отправлять посты с датой позднее, чем уже ранее отправленные. Проверьте свои настройки времени.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Incorrect time value. Check your time settings.</source>
        <translation type="unfinished">Неправильное время. Проверьте настройки даты и времени. </translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't add a redirected account as a friend</source>
        <translation type="unfinished">Ошибка добавления друга. </translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Non-authenticated email address. Please check your email and follow the link.</source>
        <translation type="unfinished">Не авторизованный email адрес. Пожалуйста проверьте почту и пройдите по ссылке.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Tags error. Try to write another tags.</source>
        <translation type="unfinished">Ошибка тегов. Введите пожалуйста другие теги.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Protocol error in </source>
        <translation type="unfinished">Ошибка протокола в </translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>This operation isn't supported by this blog-service</source>
        <translation type="unfinished">Операция не позволяется данным сервисом</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Missing required argument(s).This error may be connected with changing API. \
            Try to repeat attempt later or connect with developers</source>
        <translation type="unfinished">Пропущен требуемый аргумент(ы).Эта ошибка может быть связана с изменением API. Попытайтесь позднее или свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>This operation isn't supported by this blog-service</source>
        <translation type="unfinished">Эта операция не поддерживается данным блог-сервисом</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Too many arguments. This error may be connected with changing API. \
            Try to repeat attempt later or connect with developers </source>
        <translation type="unfinished">Слишком много аргументов.Эта ошибка может быть связана с изменением API. Попытайтесь позднее или свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid argument(s). Check your filling data. If this error repeats, try to connect with developers</source>
        <translation type="unfinished">Некоретные аргументы. Если эта ошибка повторится, свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid metadata datatype. Check your metadata. If this error repeats, try to connect with developers</source>
        <translation type="unfinished">Неверный тип метаданных. Проверьте метаданные. Если эта ошибка повторится, свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Unknown metadata. Check your metadata. If this error repeats, try to connect with developers</source>
        <translation type="unfinished">Неверные метаданные. Если эта ошибка повторится, свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>You can't edit this journal</source>
        <translation type="unfinished">Вы не можете редактировать этот журнал.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Protocol version mismatch. This error may be connected with changing API. \
            Try to repeat attempt later or connect with developers </source>
        <translation type="unfinished">Версия протокола изменилась. Эта ошибка может быть связана с изменением API. Попытайтесь позднее или свяжитесь с разработчиками.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid text encoding. Please change your locale to english language.</source>
        <translation type="unfinished">Невереная кодировка. Смените язык устройства на английский</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Parameter out of range. Please change parameter value.</source>
        <translation type="unfinished">Параметр имеет недопустимое значение. Измените значение параметра пожалуйста.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Client tried to edit with corrupt data. Preventing.</source>
        <translation type="unfinished">Была совершена попытка редактирования повреждённых данных. Предотвращено.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Invalid or malformed tag list. Check your tag list.</source>
        <translation type="unfinished">Неправильный или ошибочно-сформированный список тегов. Проверьте список тегов пожалуйста.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Message body is too long. Please cut your message. </source>
        <translation type="unfinished">Слишком длинное сообщение. Пожалуйста, уменьшите размер сообщения.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Message body is empty. Write your message.</source>
        <translation type="unfinished">Пустое сообщение. Введите текст.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Message looks like spam. Check your message. </source>
        <translation type="unfinished">Сообщение выглядит как спам. Проверьте текст сообщения.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Access of restricted feature</source>
        <translation type="unfinished">Был осуществлён доступ к запрещённой возможности.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't edit post from requested journal</source>
        <translation type="unfinished">Невозможно отредактировать пост запрошенного журнала.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't edit post in community journal</source>
        <translation type="unfinished">Невозможно отредактировать пост группы.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Can't delete post in this community journal</source>
        <translation type="unfinished">Невозможно удалить пост группы.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Action forbidden; account is temporary unavailable</source>
        <translation type="unfinished">Действие запрещено: аккаунт временно заморожен.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>This journal is temporarily in read-only mode. Try again in a couple minutes.</source>
        <translation type="unfinished">Этот журнал временно находится только в режиме чтения. Попробуйте через пару минут.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Selected journal no longer exists. Try to refresh posts.</source>
        <translation type="unfinished">Выбранный журнал больше не существует.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Account is locked and cannot be used.</source>
        <translation type="unfinished">Аккаунт заблокирован и не может быть использован.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Account is marked as a memorial.</source>
        <translation type="unfinished">Аккаунт помечен как мемориальный</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Account needs to be age verified before use. Please check your email and follow the link.</source>
        <translation type="unfinished">Необходимо подтвердить регистрацию. Пожалуйста, проверьте почту и перейдите по ссылке окончания регистрации.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Access temporarily disabled. Please try later. </source>
        <translation type="unfinished">Доступ временно закрыт. Попробуйте позже.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Not allowed to add tags to entries in this journal. Delete tags from post.</source>
        <translation type="unfinished">Добавление тегов в этот журнал запрещено. Пожалуйста, удалите теги из поста</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Must use existing tags for entries in this journal (can't create new ones)</source>
        <translation type="unfinished">Должны использоваться существующие теги в этом журнале (нельзя создавать новые).</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>Only paid users allowed to use this request </source>
        <translation type="unfinished">Данная операция разрешена только для платных пользователей.</translation>
    </message>
    <message>
        <location filename="ScriboExc.py" line="63"/>
        <source>User messaging is currently disabled. Try later.</source>
        <translation type="unfinished">Работа с сообщениями временно приостановлена. Попытайтесь позднее.</translation>
    </message>
</context>
<context>
    <name>RepeatPost</name>
    <message>
        <location filename="RepeatPost.py" line="42"/>
        <source>Select accounts and groups for sending</source>
        <translation type="unfinished">Выберите аккаунты для отправки</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="64"/>
        <source>Send</source>
        <translation type="unfinished">Отправить</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="76"/>
        <source>Service</source>
        <translation type="unfinished">Сервис</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="77"/>
        <source>Login</source>
        <translation type="unfinished">Логин</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="196"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="157"/>
        <source>Please, choose subitem for sending</source>
        <translation type="unfinished">Пожалуйста, выберите учетную запись для отправки</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="178"/>
        <source>Please, choose accounts or groups for sending</source>
        <translation type="unfinished">Выберите аккаунты для отправки</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="185"/>
        <source>Post was sent</source>
        <translation type="unfinished">Пост отправлен</translation>
    </message>
    <message>
        <location filename="RepeatPost.py" line="196"/>
        <source>Post will be lost! Continue? </source>
        <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <location filename="StartPage.py" line="41"/>
        <source>Login</source>
        <translation type="unfinished">Логин</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="43"/>
        <source>Password</source>
        <translation type="unfinished">Пароль</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="45"/>
        <source>Blog service</source>
        <translation type="unfinished">Сервис</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="58"/>
        <source>Go</source>
        <translation type="unfinished">Зайти</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="99"/>
        <source>Scribo</source>
        <translation type="unfinished">Scribo</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="99"/>
        <source>Please, fill all fields!</source>
        <translation type="unfinished">Пожалуйста, заполните все поля</translation>
    </message>
    <message>
        <location filename="StartPage.py" line="161"/>
        <source>&lt;i&gt;Welcome to Scribo,&lt;br/&gt; mobile multiblog client!&lt;/i&gt;</source>
        <translation type="unfinished">&lt;i&gt;Добро пожаловать в Скрибо,&lt;br/&gt;мобильный мультиблоговый клиент!&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ToolbarWindow</name>
    <message>
        <location filename="ToolbarWindow.py" line="48"/>
        <source>Home</source>
        <translation type="unfinished">Домой</translation>
    </message>
</context>
<context>
    <name>TreeMessage</name>
    <message>
        <location filename="TreeMessage.py" line="97"/>
        <source>Refresh</source>
        <translation type="unfinished">Обновить</translation>
    </message>
    <message>
        <location filename="TreeMessage.py" line="105"/>
        <source>Decrease</source>
        <translation type="unfinished">Уменьшить</translation>
    </message>
    <message>
        <location filename="TreeMessage.py" line="113"/>
        <source>Increase</source>
        <translation type="unfinished">Увеличить</translation>
    </message>
    <message>
        <location filename="TreeMessage.py" line="373"/>
        <source>Do you really want to delete comment?</source>
        <translation type="unfinished">Вы действительно хотите удалить комментарий?</translation>
    </message>
</context>
<context>
    <name>ComTree</name>
    <message>
        <location filename="TreeMessage.py" line="239"/>
        <source>no subject</source>
        <translation type="unfinished">без темы</translation>
    </message>
        <message>
        <location filename="TreeMessage.py" line="334"/>
        <source>unfreeze</source>
        <translation type="unfinished">разморозить</translation>
    </message>
        <message>
        <location filename="TreeMessage.py" line="337"/>
        <source>freeze</source>
        <translation type="unfinished">заморозить</translation>
    </message>
        <message>
        <location filename="TreeMessage.py" line="340"/>
        <source>unscreen</source>
        <translation type="unfinished">показать</translation>
    </message>
            <message>
        <location filename="TreeMessage.py" line="343"/>
        <source>screen</source>
        <translation type="unfinished">скрыть</translation>
    </message>
    <message>
        <location filename="TreeMessage.py" line="353"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
</context>
<context>
    <name>ViewMessage</name>
    <message>
        <location filename="ViewMessage.py" line="119"/>
        <source>no subject</source>
        <translation type="unfinished">без темы</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="263"/>
        <source>Previous</source>
        <translation type="unfinished">Пред.</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="271"/>
        <source>Next</source>
        <translation type="unfinished">След.</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="279"/>
        <source>Decrease</source>
        <translation type="unfinished">Уменьшить</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="287"/>
        <source>Increase</source>
        <translation type="unfinished">Увеличить</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="295"/>
        <source>Write comment</source>
        <translation type="unfinished">Ответить</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="303"/>
        <source>Edit</source>
        <translation type="unfinished">Изменить</translation>
    </message>
    <message>
        <location filename="ViewMessage.py" line="311"/>
        <source>Comments</source>
        <translation type="unfinished">Комментарии</translation>
    </message>
</context>
</TS>
